package com.ruoyi.project.plant.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.plant.mapper.TConfRoomMapper;
import com.ruoyi.project.plant.domain.TConfRoom;
import com.ruoyi.project.plant.service.ITConfRoomService;

/**
 * 会议室管理Service业务层处理
 *
 * @author ssy
 * @date 2024-04-29
 */
@Service
public class TConfRoomServiceImpl implements ITConfRoomService
{
    @Autowired
    private TConfRoomMapper tConfRoomMapper;

    /**
     * 查询会议室管理
     *
     * @param id 会议室管理ID
     * @return 会议室管理
     */
    @Override
    public TConfRoom selectTConfRoomById(Long id)
    {
        return tConfRoomMapper.selectTConfRoomById(id);
    }

    /**
     * 查询会议室管理列表
     *
     * @param tConfRoom 会议室管理
     * @return 会议室管理
     */
    @Override
    public List<TConfRoom> selectTConfRoomList(TConfRoom tConfRoom)
    {
        return tConfRoomMapper.selectTConfRoomList(tConfRoom);
    }

    /**
     * 新增会议室管理
     *
     * @param tConfRoom 会议室管理
     * @return 结果
     */
    @Override
    public int insertTConfRoom(TConfRoom tConfRoom)
    {
        return tConfRoomMapper.insertTConfRoom(tConfRoom);
    }

    /**
     * 修改会议室管理
     *
     * @param tConfRoom 会议室管理
     * @return 结果
     */
    @Override
    public int updateTConfRoom(TConfRoom tConfRoom)
    {
        return tConfRoomMapper.updateTConfRoom(tConfRoom);
    }

    /**
     * 批量删除会议室管理
     *
     * @param ids 需要删除的会议室管理ID
     * @return 结果
     */
    @Override
    public int deleteTConfRoomByIds(Long[] ids)
    {
        return tConfRoomMapper.deleteTConfRoomByIds(ids);
    }

    /**
     * 删除会议室管理信息
     *
     * @param id 会议室管理ID
     * @return 结果
     */
    @Override
    public int deleteTConfRoomById(Long id)
    {
        return tConfRoomMapper.deleteTConfRoomById(id);
    }
}
